[][src]Struct gfx::platform::freetype::font_template::FontTemplateData

pub struct FontTemplateData {
    pub bytes: Option<Vec<u8>>,
    pub identifier: Atom,
}

Platform specific font representation for Linux. The identifier is an absolute path, and the bytes field is the loaded data that can be passed to freetype and Raqote directly.

Fields

bytes: Option<Vec<u8>>identifier: Atom

Implementations

impl FontTemplateData[src]

pub fn new(
    identifier: Atom,
    bytes: Option<Vec<u8>>
) -> Result<FontTemplateData, Error>
[src]

pub fn bytes(&self) -> Vec<u8>[src]

Returns a clone of the data in this font. This may be a hugely expensive operation (depending on the platform) which performs synchronous disk I/O and should never be done lightly.

pub fn bytes_if_in_memory(&self) -> Option<Vec<u8>>[src]

Returns a clone of the bytes in this font if they are in memory. This function never performs disk I/O.

pub fn native_font(&self) -> Option<NativeFontHandle>[src]

Returns the native font that underlies this font template, if applicable.